import marimo

__generated_with = "0.1.50"
app = marimo.App(width="full", layout_file="layouts/app.grid.json")


@app.cell
def __():
    import marimo as mo
    import altair as alt
    import vega_datasets as vega

    return alt, mo, vega


@app.cell
def __(vega):
    cars = vega.data.cars()
    columns = cars.columns.tolist()
    return cars, columns


@app.cell
def __(columns, mo):
    x_axis = mo.ui.dropdown(
        options=columns,
        value="Horsepower",
        label="X Axis:",
        full_width=True,
    )
    y_axis = mo.ui.dropdown(
        options=columns,
        value="Miles_per_Gallon",
        label="Y Axis:",
        full_width=True,
    )
    color = mo.ui.dropdown(
        options=columns,
        value="Origin",
        label="Color:",
        full_width=True,
    )
    shape = mo.ui.dropdown(
        options=["square", "circle", "point", "bar"],
        value="circle",
        label="Shape:",
        full_width=True,
    )

    clear = mo.ui.button(
        label="Clear",
        full_width=True,
    )

    mo.vstack(
        [
            mo.md("## Controls"),
            x_axis,
            y_axis,
            color,
            shape,
        ]
    )
    return clear, color, shape, x_axis, y_axis


@app.cell
def __(alt, cars, color, mo, shape, x_axis, y_axis):
    _chart = alt.Chart(
        data=cars,
        mark=shape.value,
        encoding={
            "x": alt.X(
                field=x_axis.value,
                type="quantitative",
            ),
            "y": alt.Y(
                field=y_axis.value,
                type="quantitative",
            ),
            "color": alt.Color(
                field=color.value,
                type="nominal",
            ),
        },
    )
    chart = mo.ui.altair_chart(_chart)
    chart
    return chart,


@app.cell
def __(chart, mo):
    mo.ui.table(chart.value, selection=None)
    return


if __name__ == "__main__":
    app.run()
